# -*- coding: utf-8 -*-

"""Top-level package for PGSync."""

__author__ = "Tolu Aina"
__email__ = "tolu@pgsync.com"
__version__ = "2.3.3"
